-- ----------------------------------------------------------------------
-- @(#) upgrade_perf_schema.sql 1.3.0 07/12/08 17:57:49
-- @(#) 
-- Copyright 2006 Vallent Corp.
-- ----------------------------------------------------------------------

set timing on;
set serveroutput on size 1000000;
set lines 200;

DECLARE
   vOldVersion INTEGER := 0;
BEGIN

   BEGIN
      SELECT 1
        INTO vOldVersion
        FROM pe_system
       WHERE ldap_url like '2.2.5.1.%' 
          OR ldap_url like '2.2.5.0.%';

      EXCEPTION WHEN NO_DATA_FOUND THEN
         vOldVersion := 0;

   END;

   IF vOldVersion != 1 THEN
      dbms_output.put_line('PE_PERF tables up to date');
      RETURN;
   END IF;

   dbms_output.put_line('Downgrading PE_PERF tables');

run_sql('DROP VIEW pe_perf_report_db_stats_vw');
run_sql('DROP VIEW pe_perf_stats_report_queue_vw');

run_sql('DROP SEQUENCE pe_seq_perf_db_stat');

run_sql('DROP TABLE pe_perf_stats_general');
run_sql('DROP TABLE pe_perf_stats_report');
run_sql('DROP TABLE pe_perf_stats_report_strings');
run_sql('DROP TABLE pe_perf_stats_report_queue');
run_sql('DROP TABLE pe_perf_db_stat_name');
run_sql('DROP TABLE pe_perf_report_db_stats');
run_sql('DROP TABLE pe_perf_report_db_stats_tmp');

DELETE FROM part_tables 
 WHERE TABLE_NAME like 'PE_PERF%';

DELETE FROM subclass_table 
 WHERE name = 'PerformanceStats';
 
-- ------------------------------------------------------------------------
-- Stores performance statistics of the pweb environment
-- at certain intervals marked by the tstamp column.
-- Currently the intervals are 30 minutes.
-- ------------------------------------------------------------------------
run_sql( ' CREATE TABLE pe_perf_stats_general '
|| ' ( '
   || ' tstamp                  DATE NOT NULL, '
   || ' active_user_count       INTEGER NOT NULL, '
   || ' max_memory              INTEGER NOT NULL, '
   || ' available_memory        INTEGER NOT NULL, '
   || ' report_started_count    INTEGER NOT NULL, '
   || ' report_completed_count  INTEGER NOT NULL, '
   || ' report_pending_count    INTEGER NOT NULL, '
   || ' CONSTRAINT pk_perf_stats_general PRIMARY KEY(tstamp) '
|| ' ) '
 || ' ORGANIZATION INDEX '
 || ' PARTITION BY RANGE ( tstamp ) '
 || ' ( '
   || ' PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
 || ' ) '
     || ' PCTFREE 0 '
     || ' TABLESPACE TRAFFIC_SMALL '
 );

-- ------------------------------------------------------------------------
-- Stores the number of reports completed per datasource per user
-- at certain intervals marked by the tstamp column.
-- Currently the intervals are 30 minutes.
-- ------------------------------------------------------------------------
run_sql( ' CREATE TABLE pe_perf_stats_report '
|| ' ( '
   || ' tstamp                  DATE NOT NULL, '
   || ' datasource_id           INTEGER NOT NULL, '
   || ' user_id                 INTEGER NOT NULL, '
   || ' report_completed_count  INTEGER NOT NULL, '
   || ' CONSTRAINT pk_perf_stats_report PRIMARY KEY(tstamp, datasource_id, user_id) '
|| ' ) '
 || ' ORGANIZATION INDEX '
 || ' PARTITION BY RANGE ( tstamp ) '
 || ' ( '
   || ' PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
 || ' ) '
     || ' PCTFREE 0 '
     || ' TABLESPACE TRAFFIC_SMALL '
 );

-- ------------------------------------------------------------------------
  run_sql( ' INSERT INTO subclass_table ( id, class_id, name ) '
    || ' ( SELECT subclass_table_seq.NEXTVAL, id, ''PerformanceStats'' '
    || ' FROM class_table ct '
    || ' WHERE LOWER( ct.name ) = ''part maint'' '
    || ' AND NOT EXISTS (SELECT 1 FROM subclass_table where name = ''PerformanceStats'' ))'
  );


  run_sql( ' INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, run_daily, needs_purge, future_part, past_part ) '
    || ' (SELECT part_table_seq.NEXTVAL, ''PE_PERF_STATS_GENERAL'', ''TRAFFIC_SMALL'', ''Y'', ''Y'', 5, 90  '
    || ' FROM subclass_table st '
    || ' WHERE name = ''PerformanceStats'' '
    || ' AND NOT EXISTS (SELECT 1 FROM part_tables where table_name = ''PE_PERF_STATS_GENERAL'' ))'
  );


  run_sql( ' INSERT INTO subclass_map ( subclass_id, object_id ) '
    || ' ( SELECT id, part_table_id '
    || ' FROM subclass_table st, part_tables pt '
    || ' WHERE st.name = ''PerformanceStats'' '
    || ' AND pt.table_name = ''PE_PERF_STATS_GENERAL''  '
    || ' AND NOT EXISTS (SELECT 1 FROM subclass_map '
    || '  where subclass_id = st.id and object_id = pt.part_table_id ))'
  );

  run_sql( ' INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, run_daily, needs_purge, future_part, past_part ) '
    || ' (SELECT part_table_seq.NEXTVAL, ''PE_PERF_STATS_REPORT'', ''TRAFFIC_SMALL'', ''Y'', ''Y'', 5, 90  '
    || ' FROM subclass_table st '
    || ' WHERE name = ''PerformanceStats'' '
    || ' AND NOT EXISTS (SELECT 1 FROM part_tables where table_name = ''PE_PERF_STATS_REPORT'' ))'
  );

  run_sql( ' INSERT INTO subclass_map ( subclass_id, object_id ) '
    || ' ( SELECT id, part_table_id '
    || ' FROM subclass_table st, part_tables pt '
    || ' WHERE st.name = ''PerformanceStats'' '
    || ' AND pt.table_name = ''PE_PERF_STATS_REPORT'' '
    || ' AND NOT EXISTS (SELECT 1 FROM subclass_map '
    || '  where subclass_id = st.id and object_id = pt.part_table_id ))'
  );

  COMMIT;

    init_part_tab ( 'PE_PERF_STATS_GENERAL' );
    init_part_tab ( 'PE_PERF_STATS_REPORT' );
END;
/

